pub struct KeyValuePair { /* private fields */ }Implementations
Sourceimpl KeyValuePair
impl KeyValuePair
Sourcepub fn into_tuple(self) -> (String, Object)
pub fn into_tuple(self) -> (String, Object)
Consumes the KeyValuePair and returns a (key, value) tuple.
Sourcepub fn into_value(self) -> Object
pub fn into_value(self) -> Object
Consumes the KeyValuePair and returns the value.
Sourcepub fn key_mut(&mut self) -> &mut String
pub fn key_mut(&mut self) -> &mut String
Returns an exclusive reference to the key of the KeyValuePair.
Sourcepub fn tuple(&self) -> (&String, &Object)
pub fn tuple(&self) -> (&String, &Object)
Returns references to both the key and value as a tuple.